(function() {
	var shouldShowLoader = true,
		isDeviceReady = false,
		isAnonymous = true,
		shouldShowUpdateMessage = false,
		shouldShowOfflineMessage = false,
		protocol = "https://",
		publicUrl = "www.healee.com",
		url = window.healeeUrl || publicUrl;

	localStorage.setItem("healeeUrl", url);

	if (url !== publicUrl) {
		protocol = "http://";
	}

	window.showLoader = function() {
		if (shouldShowLoader) {
			app.showLoading();
		}
	};

	var app = new kendo.mobile.Application(document.body),
		socialUserString = localStorage.getItem("healIsSocialUser") || "",
		currentUserString, currentUser;

	if (socialUserString) {
		isAnonymous = !JSON.parse(socialUserString);
	}

	if (isAnonymous) {
		currentUserString = localStorage.getItem("healCurrentUser") || "";

		if (currentUserString) {
			currentUser = JSON.parse(currentUserString);
		}
	}

	function hideLoader() {
		if (app) {
			app.hideLoading();
		}
		shouldShowLoader = false;
	}

	function showUpdateMessage() {
		hideLoader();
		navigator.notification.alert("A new version of Healee is available. Please update now.", function() {
			window.open("http://appstore.com/" + window.healeeProducer, "_system");
		});
	}

	function showOfflineMessage() {
		hideLoader();
		navigator.notification.alert("There was a problem connecting to Healee. Please try again.", function() {
			getUserData();
		});
	}

	function navigate(userData, shouldSave) {
		if (userData && shouldSave) {
			if (userData.user) {
				localStorage.setItem("healCurrentUser", JSON.stringify(userData.user));
			}
			localStorage.setItem("heal", JSON.stringify(userData));
		}
		if (userData && (userData.version !== window.healeeVersion) && userData.requiresUpdate) {
			shouldShowUpdateMessage = true;
			if (isDeviceReady) {
				prepareUpdateMessage();
			}
		} else {
			localStorage.setItem("healIsSocialUser", !isAnonymous);
			if (userData) {
				document.location = "home.html";
			} else {
				if (isAnonymous) {
					shouldShowOfflineMessage = true;
					if (isDeviceReady) {
						showOfflineMessage();
					}
				} else {
					document.location = "login.html";
				}
			}
		}
	}

	function prepareUpdateMessage() {
		showUpdateMessage();
		document.addEventListener("resume", function() {
			showUpdateMessage();
		});
	}

	function navigateOffline() {
		var userData = localStorage.getItem("heal");
		if (userData) {
			userData = JSON.parse(userData);
		}
		navigate(userData, false);
	}

	document.addEventListener("deviceready", function() {
		isDeviceReady = true;
		if (shouldShowUpdateMessage) {
			prepareUpdateMessage();
		} else if (shouldShowOfflineMessage) {
			showOfflineMessage();
		}
	});

	if (!navigator.onLine) {
		navigateOffline();
		return;
	}

	function getUserData() {
		$.ajax({
			cache: false,
			type: "GET",
			async: true,
			dataType: "json",
			contentType: "application/json; charset=utf-8",
			url: protocol + url + (isAnonymous ? "/user-data-mobile/" + (currentUserString || "_") : "/user-data"),
			success: function(result) {
				navigate(result, true);
			},
			error: function(xhr) {
				if (xhr.status === 0) {
					navigateOffline();
				} else {
					hideLoader();
					alert("service error: " + xhr.responseText);
				}
			}
		});
	}

	getUserData();
})();